summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoView.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoView.h')
-rw-r--r--lib/kofficecore/KoView.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/kofficecore/KoView.h b/lib/kofficecore/KoView.h
index a0113e07..b53c339a 100644
--- a/lib/kofficecore/KoView.h
+++ b/lib/kofficecore/KoView.h
@@ -27,12 +27,12 @@
#include <KoChild.h>
#include <koffice_export.h>
-class KAction;
-class KActionCollection;
+class TDEAction;
+class TDEActionCollection;
class TQCustomEvent;
class KoDocument;
class KoMainWindow;
-class KMainWindow;
+class TDEMainWindow;
class KoViewPrivate;
class KoViewChild;
class KoFrame;
@@ -101,7 +101,7 @@ public:
/**
* Returns the action described action object. In fact only the "name" attribute
* of @p element is of interest here. The method searches in the
* KActionCollection of this view.
*
* Please notice that KoView indirectly inherits KXMLGUIClient.
*
@@ -109,7 +109,7 @@ public:
* @see KXMLGUIClient::actionCollection
* @see KoDocument::action
*/
- virtual KAction *action( const TQDomElement &element ) const;
+ virtual TDEAction *action( const TQDomElement &element ) const;
/**
* Retrieves the document that is hit. This can be an embedded document.
@@ -321,10 +321,10 @@ public:
KoMainWindow * shell() const;
/**
* @return the KMainWindow in which this view is currently.
* This one should never return 0L, in a KDE app.
*/
- KMainWindow* mainWindow() const;
+ TDEMainWindow* mainWindow() const;
/**
* @return the statusbar of the KoMainWindow in which this view is currently.
@@ -461,7 +461,7 @@ protected slots:
virtual void slotAutoScroll( );
private:
- KAction *actionNewView;
+ TDEAction *actionNewView;
virtual void setupGlobalActions( void );
KoViewPrivate *d;
int autoScrollAcceleration( int offset ) const;
@@ -101,7 +101,7 @@ public:
* Returns the action described action object. In fact only the "name" attribute
* of @p element is of interest here. The method searches in the
- * KActionCollection of this view.
+ * TDEActionCollection of this view.
*
* Please notice that KoView indirectly inherits KXMLGUIClient.
@@ -321,10 +321,10 @@ public:
KoMainWindow * shell() const;
/**
- * @return the KMainWindow in which this view is currently.
+ * @return the TDEMainWindow in which this view is currently.
* This one should never return 0L, in a KDE app.
*/